@@ -3,9 +3,12 @@ import os
 from cement import App
 
 import deployfish_mysql.adapters  # noqa:F401
-from .controllers.mysql import MysqlController
 
-__version__ = "1.2.9"
+from .controllers.mysql import MysqlController
+from .hooks import pre_config_interpolate_add_mysql_section
+
+
+__version__ = "1.2.14"
 
 
 def add_template_dir(app: App):
@@ -16,3 +19,4 @@ def add_template_dir(app: App):
 def load(app: App) -> None:
     app.handler.register(MysqlController)
     app.hook.register('post_setup', add_template_dir)
+    app.hook.register('pre_config_interpolate', pre_config_interpolate_add_mysql_section)
